Wow - org-notify

2019-11-08 Thread Nathan Neff
I have not put effort estimates on my tasks for a long time.

Tonight, I was playing chess and saw a "notify" message come up on my
Linux box that  should be finished by now.

Wow - I never knew org-mode had that built-in!  I ran a git-blame on the
org-source
code [1] and it's been a long time, right?  I haven't tested whether it
sends a Growl notification
on OSX but that's really cool!

(It was kinda creepy at first, though)

Thanks,
--Nate

[1]
https://github.com/emacs-mirror/emacs/blame/f8284f1e408b38e6a3c0e2a1d5a465fefac6800a/lisp/org/org-clock.el#L698


Bug: LaTeX output of numbered TODO plain list items lose numbering. [9.1.9 (release_9.1.9-65-g5e4542 @ /usr/share/emacs/27.0.50/lisp/org/)]

2019-11-08 Thread Brian Carlson
Remember to cover the basics, that is, what you expected to happen and
what in fact did happen.  You don't know how to make a good report?  See

 https://orgmode.org/manual/Feedback.html#Feedback

Your bug report will be posted to the Org mailing list.

So it seems that the numbering of numbered items in a plain list are not
maintained when the numbered item is also a TODO plain list item.

Here is how I produced the issue:

$ emacs -Q

I created a very simple org-mode file:
--8<---cut here---start->8---
* Test file
  1. [ ] item
  2. item 2
  3. item 3
--8<---cut here---end--->8---

I then used the export facilities to create a PDF: C-c C-e l o

I expected to see a PDF that looked like:
--8<---cut here---start->8---
Contents

1 Test File

1  Test File
   1. [] item
   2. item 2
   3. item 3
--8<---cut here---end--->8---

Instead I see a pdf that has the following:
--8<---cut here---start->8---
Contents

1 Test File

1  Test File
   [] item
   1. item 2
   2. item 3
--8<---cut here---end--->8---

Notice how the "1." was removed in the generated PDF from the first item
and the numbering started from 1. on "item 2"

This used to work, but I'm not exactly certain when it changed.

It *appears* that the generated \item for enumeration is incorrect?
The .tex file contains the following:
 \item[{$\square$}] item

I /think/ that this should be:
   \item{$\square$} item

Maybe the [ and ] are not being stripped and converted into the {$\square$}, 
but are rather being left and ending up
with [{$\square$}].

(The same thing happens with the \boxtimes for "completed" TODOs.


If that is the case then I /think/ that this patch would fix it:
diff --git a/lisp/ox-latex.el b/lisp/ox-latex.el
index 832d9bf8..b9734443 100644
--- a/lisp/ox-latex.el
+++ b/lisp/ox-latex.el
@@ -2208,9 +2208,9 @@ contextual information."
"\\item"
(cond
 ((and checkbox tag)
- (format "[{%s %s}] %s" checkbox tag tag-footnotes))
+ (format "{%s %s} %s" checkbox tag tag-footnotes))
 ((or checkbox tag)
- (format "[{%s}] %s" (or checkbox tag) tag-footnotes))
+ (format "{%s} %s" (or checkbox tag) tag-footnotes))
 ;; Without a tag or a check-box, if CONTENTS starts with
 ;; an opening square bracket, add "\relax" to "\item",
 ;; unless the brackets comes from an initial export

I haven't done any thorough testing, just looking where I thought the issue 
might be.

Thanks for all the great work on Org Mode,
;-b



Emacs  : GNU Emacs 27.0.50 (build 1, x86_64-pc-linux-gnu, GTK+ Version 3.18.9)
 of 2019-09-04
Package: Org mode version 9.1.9 (release_9.1.9-65-g5e4542 @ 
/usr/share/emacs/27.0.50/lisp/org/)

current state:
==
(setq
 org-src-mode-hook '(org-src-babel-configure-edit-buffer
 org-src-mode-configure-edit-buffer)
 org-after-todo-state-change-hook '(org-clock-out-if-current)
 org-metadown-hook '(org-babel-pop-to-session-maybe)
 org-clock-out-hook '(org-clock-remove-empty-clock-drawer)
 org-html-format-inlinetask-function 
'org-html-format-inlinetask-default-function
 org-odt-format-headline-function 'org-odt-format-headline-default-function
 org-ascii-format-inlinetask-function 'org-ascii-format-inlinetask-default
 org-mode-hook '(#[0 "\300\301\302\303\304$\207"
   [add-hook change-major-mode-hook org-show-block-all append
local]
   5]
 #[0 "\300\301\302\303\304$\207"
   [add-hook change-major-mode-hook org-babel-show-result-all
append local]
   5]
 org-babel-result-hide-spec org-babel-hide-all-hashes)
 org-odt-format-drawer-function #[514 "\207" [] 3 "\n\n(fn NAME CONTENTS)"]
 org-archive-hook '(org-attach-archive-delete-maybe)
 org-confirm-elisp-link-function 'yes-or-no-p
 org-agenda-before-write-hook '(org-agenda-add-entry-text)
 org-metaup-hook '(org-babel-load-in-session-maybe)
 org-bibtex-headline-format-function #[257 "\300\236A\207" [:title] 3 "\n\n(fn 
ENTRY)"]
 org-latex-format-drawer-function #[514 "\207" [] 3 "\n\n(fn _ CONTENTS)"]
 org-babel-pre-tangle-hook '(save-buffer)
 org-tab-first-hook '(org-babel-hide-result-toggle-maybe
  org-babel-header-arg-expand)
 org-ascii-format-drawer-function #[771 "\207" [] 4 "\n\n(fn NAME CONTENTS 
WIDTH)"]
 org-occur-hook '(org-first-headline-recenter)
 org-cycle-hook '(org-cycle-hide-archived-subtrees org-cycle-hide-drawers
  org-cycle-show-empty-lines
  org-optimize-window-after-visibility-change)
 org-speed-command-hook '(org-speed-command-activate

Wow - clockcheck

2019-11-08 Thread Nathan Neff
Another zesty discovery that I made today after using org for like 10 years
is "clockcheck" mode in Agenda (v c).

I have never known about that (or forgot about it).  I haven't run the
git-blame on that feature though, I don't want to have a big gap in my
clock times between tasks :)

Thanks,
--Nate


Re: Finally figuring out some ob-sqlite stuff -- for worg?

2019-11-08 Thread Eric Abrahamsen
"Thomas S. Dye"  writes:

> Aloha Eric,
>
> Good news.  Yes, please feel free to update the Worg SQLite page.
>
> IIRC, you can get permission from Bastien to push changes and then you
> can edit Worg at will.

Cool! Bastien, can you help me get write access to Worg?

Thanks,
Eric




Re: Anyone use 3rd party search tools w/org-mode?

2019-11-08 Thread Roland Everaert
Is it me or Swish-e is dead?

The url www.swish-e.org, leads to a whisky e-shop oO.
Eric Abrahamsen writes:

> John Kitchin  writes:
>
>> The way I got Swish to index org files was to create a script that
>> generated an xml file
>> (https://kitchingroup.cheme.cmu.edu/blog/2015/07/06/Indexing-headlines-in-org-files-with-swish-e-with-laser-sharp-results/)
>> or html
>> (http://kitchingroup.cheme.cmu.edu/blog/2015/07/03/Using-swish-e-to-index-org-files-as-html/)
>> that it could index. This is probably a general strategy for these tools.
>
> That seems unfortunately roundabout, but I don't know enough about the
> various FTS engines to know if they could be taught to read Org files 
> directly...


-- 
Luke, use the FOSS

Sent from Emacs



[PATCH] ob-plantuml: Support for plantuml as well as the current java+jar solution

2019-11-08 Thread Terje Larsen
I have been missing this feature for a while and noticed it had already
been requested before (2014), See:
https://lists.gnu.org/archive/html/emacs-orgmode/2016-08/msg00105.html

With this patch you can switch between using jar or plantuml. The idea
partly stemmed from plantuml-mode and my inability to use the default
implementation. You can see the implementation for plantuml-mode here:
https://github.com/skuro/plantuml-mode/pull/102/files

My patch is available here:
https://code.orgmode.org/terlar/org-mode/commit/fbe245c0b09513ee5a6d3b189e112708b9d08da0

And also see attached within this mail.
>From fbe245c0b09513ee5a6d3b189e112708b9d08da0 Mon Sep 17 00:00:00 2001
From: Terje Larsen 
Date: Fri, 8 Nov 2019 10:25:49 +0100
Subject: [PATCH] ob-plantuml: Add support for plantuml executable

* lisp/ob-plantuml (org-babel-variable-assignments:plantuml): Support
using plantuml executable instead of jar.

Some systems come with an executable for plantuml instead of a specific
JAR file. This adds support for two different modes:
- jar :: using java together with a JAR (previous behavior)
- plantuml :: using a PlantUML executable

The PlantUML executable can be configured via
`org-plantuml-executable-path` and also the arguments that will be given
via `org-plantuml-executable-args`.
---
 lisp/ob-plantuml.el | 94 +
 1 file changed, 60 insertions(+), 34 deletions(-)

diff --git a/lisp/ob-plantuml.el b/lisp/ob-plantuml.el
index 09c9a3334..388d9f1b9 100644
--- a/lisp/ob-plantuml.el
+++ b/lisp/ob-plantuml.el
@@ -31,7 +31,7 @@
 ;;; Requirements:
 
 ;; plantuml | http://plantuml.sourceforge.net/
 ;; plantuml.jar | `org-plantuml-jar-path' should point to the jar file
 
 ;;; Code:
 (require 'ob)
@@ -46,6 +46,31 @@
   :version "24.1"
   :type 'string)
 
+(defcustom org-plantuml-exec-mode 'jar
+  "Method to use for PlantUML diagram generation.
+`jar' means to use java together with the JAR.
+The JAR can be configured via `org-plantuml-jar-path'.
+
+`plantuml' means to use the PlantUML executable.
+The executable can be configured via `org-plantuml-executable-path'.
+You can also configure extra arguments via `org-plantuml-executable-args'."
+  :group 'org-babel
+  :version "24.1"
+  :type 'symbol
+  :options '(jar plantuml))
+
+(defcustom org-plantuml-executable-path "plantuml"
+  "Path to the PlantUML executable."
+  :group 'org-babel
+  :version "24.1"
+  :type 'string)
+
+(defcustom org-plantuml-executable-args (list "-headless")
+  "The arguments passed to plantuml executable when executing PlantUML."
+  :group 'org-babel
+  :version "24.1"
+  :type '(repeat string))
+
 (defun org-babel-variable-assignments:plantuml (params)
   "Return a list of PlantUML statements assigning the block's variables.
 PARAMS is a property list of source block parameters, which may
@@ -82,40 +107,41 @@ This function is called by `org-babel-execute-src-block'."
 	 (cmdline (cdr (assq :cmdline params)))
 	 (in-file (org-babel-temp-file "plantuml-"))
 	 (java (or (cdr (assq :java params)) ""))
+	 (executable (cond ((eq org-plantuml-exec-mode 'plantuml) org-plantuml-executable-path)
+			   (t "java")))
+	 (executable-args (cond ((eq org-plantuml-exec-mode 'plantuml) org-plantuml-executable-args)
+(t (cond ((string= "" org-plantuml-jar-path)
+	  (error "`org-plantuml-jar-path' is not set"))
+	 ((not (file-exists-p org-plantuml-jar-path))
+	  (error "Could not find plantuml.jar at %s" org-plantuml-jar-path))
+	 (t (list java
+		  "-jar"
+		  (shell-quote-argument
+		   (expand-file-name org-plantuml-jar-path
 	 (full-body (org-babel-plantuml-make-body body params))
-	 (cmd (if (string= "" org-plantuml-jar-path)
-		  (error "`org-plantuml-jar-path' is not set")
-		(concat "java " java " -jar "
-			(shell-quote-argument
-			 (expand-file-name org-plantuml-jar-path))
-			(if (string= (file-name-extension out-file) "png")
-			" -tpng" "")
-			(if (string= (file-name-extension out-file) "svg")
-			" -tsvg" "")
-			(if (string= (file-name-extension out-file) "eps")
-			" -teps" "")
-			(if (string= (file-name-extension out-file) "pdf")
-			" -tpdf" "")
-			(if (string= (file-name-extension out-file) "tex")
-			" -tlatex" "")
-			(if (string= (file-name-extension out-file) "vdx")
-			" -tvdx" "")
-			(if (string= (file-name-extension out-file) "xmi")
-			" -txmi" "")
-			(if (string= (file-name-extension out-file) "scxml")
-			" -tscxml" "")
-			(if (string= (file-name-extension out-file) "html")
-			" -thtml" "")
-			(if (string= (file-name-extension out-file) "txt")
-			" -ttxt" "")
-			(if (string= (file-name-extension out-file) "utxt")
-			" -utxt" "")
-			" -p " cmdline " < "
-			(org-babel-process-file-name in-file)
-			" > "
-			(org-babel-process-file-name out-file)
-(unless (file-exists-p org-plantuml-jar-path)
@@ -31,7 +31,7 @@
 
 ;; plantuml | http://plantuml.sourceforge.net/
-;; plantuml.jar | `org-plantuml-jar-path' should point to the jar file
+;; plantuml.jar | `org-plantuml-jar-path' should point to the jar file (when exec mode is `jar')
 
 ;;; Code:

Re: Anyone use 3rd party search tools w/org-mode?

2019-11-08 Thread Roland Everaert
Good to know, I will have a look at it when time permit.
Russell Adams writes:

> Recoll is xaipan based.
>
> On Fri, Nov 08, 2019 at 08:28:22AM -0500, John Kitchin wrote:
>> It could be dead. At the time I worked with it, the project had already
>> switched to a library form that was not directly useful to me, and the
>> original swish project was not being further developed. These days, I would
>> look to something like xapian or postgresql I think (assuming sqlite is not
>> sufficient for your needs).
>>
>> John
>>
>> ---
>> Professor John Kitchin
>> Doherty Hall A207F
>> Department of Chemical Engineering
>> Carnegie Mellon University
>> Pittsburgh, PA 15213
>> 412-268-7803
>> @johnkitchin
>> http://kitchingroup.cheme.cmu.edu
>>
>>
>>
>> On Fri, Nov 8, 2019 at 8:13 AM Roland Everaert  wrote:
>>
>> > Is it me or Swish-e is dead?
>> >
>> > The url www.swish-e.org, leads to a whisky e-shop oO.
>> > Eric Abrahamsen writes:
>> >
>> > > John Kitchin  writes:
>> > >
>> > >> The way I got Swish to index org files was to create a script that
>> > >> generated an xml file
>> > >> (
>> > https://kitchingroup.cheme.cmu.edu/blog/2015/07/06/Indexing-headlines-in-org-files-with-swish-e-with-laser-sharp-results/
>> > )
>> > >> or html
>> > >> (
>> > http://kitchingroup.cheme.cmu.edu/blog/2015/07/03/Using-swish-e-to-index-org-files-as-html/
>> > )
>> > >> that it could index. This is probably a general strategy for these
>> > tools.
>> > >
>> > > That seems unfortunately roundabout, but I don't know enough about the
>> > > various FTS engines to know if they could be taught to read Org files
>> > directly...
>> >
>> >
>> > --
>> > Luke, use the FOSS
>> >
>> > Sent from Emacs
>> >
>> >
>
>
> --
> Russell Adamsrlad...@adamsinfoserv.com
>
> PGP Key ID: 0x1160DCB3   http://www.adamsinfoserv.com/
>
> Fingerprint:1723 D8CA 4280 1EC9 557F  66E8 1154 E018 1160 DCB3


-- 
Luke, use the FOSS

Sent from Emacs



Re: Anyone use 3rd party search tools w/org-mode?

2019-11-08 Thread John Kitchin
It could be dead. At the time I worked with it, the project had already
switched to a library form that was not directly useful to me, and the
original swish project was not being further developed. These days, I would
look to something like xapian or postgresql I think (assuming sqlite is not
sufficient for your needs).

John

---
Professor John Kitchin
Doherty Hall A207F
Department of Chemical Engineering
Carnegie Mellon University
Pittsburgh, PA 15213
412-268-7803
@johnkitchin
http://kitchingroup.cheme.cmu.edu



On Fri, Nov 8, 2019 at 8:13 AM Roland Everaert  wrote:

> Is it me or Swish-e is dead?
>
> The url www.swish-e.org, leads to a whisky e-shop oO.
> Eric Abrahamsen writes:
>
> > John Kitchin  writes:
> >
> >> The way I got Swish to index org files was to create a script that
> >> generated an xml file
> >> (
> https://kitchingroup.cheme.cmu.edu/blog/2015/07/06/Indexing-headlines-in-org-files-with-swish-e-with-laser-sharp-results/
> )
> >> or html
> >> (
> http://kitchingroup.cheme.cmu.edu/blog/2015/07/03/Using-swish-e-to-index-org-files-as-html/
> )
> >> that it could index. This is probably a general strategy for these
> tools.
> >
> > That seems unfortunately roundabout, but I don't know enough about the
> > various FTS engines to know if they could be taught to read Org files
> directly...
>
>
> --
> Luke, use the FOSS
>
> Sent from Emacs
>
>


Re: Anyone use 3rd party search tools w/org-mode?

2019-11-08 Thread Russell Adams
Recoll is xaipan based.

On Fri, Nov 08, 2019 at 08:28:22AM -0500, John Kitchin wrote:
> It could be dead. At the time I worked with it, the project had already
> switched to a library form that was not directly useful to me, and the
> original swish project was not being further developed. These days, I would
> look to something like xapian or postgresql I think (assuming sqlite is not
> sufficient for your needs).
>
> John
>
> ---
> Professor John Kitchin
> Doherty Hall A207F
> Department of Chemical Engineering
> Carnegie Mellon University
> Pittsburgh, PA 15213
> 412-268-7803
> @johnkitchin
> http://kitchingroup.cheme.cmu.edu
>
>
>
> On Fri, Nov 8, 2019 at 8:13 AM Roland Everaert  wrote:
>
> > Is it me or Swish-e is dead?
> >
> > The url www.swish-e.org, leads to a whisky e-shop oO.
> > Eric Abrahamsen writes:
> >
> > > John Kitchin  writes:
> > >
> > >> The way I got Swish to index org files was to create a script that
> > >> generated an xml file
> > >> (
> > https://kitchingroup.cheme.cmu.edu/blog/2015/07/06/Indexing-headlines-in-org-files-with-swish-e-with-laser-sharp-results/
> > )
> > >> or html
> > >> (
> > http://kitchingroup.cheme.cmu.edu/blog/2015/07/03/Using-swish-e-to-index-org-files-as-html/
> > )
> > >> that it could index. This is probably a general strategy for these
> > tools.
> > >
> > > That seems unfortunately roundabout, but I don't know enough about the
> > > various FTS engines to know if they could be taught to read Org files
> > directly...
> >
> >
> > --
> > Luke, use the FOSS
> >
> > Sent from Emacs
> >
> >


--
Russell Adamsrlad...@adamsinfoserv.com

PGP Key ID: 0x1160DCB3   http://www.adamsinfoserv.com/

Fingerprint:1723 D8CA 4280 1EC9 557F  66E8 1154 E018 1160 DCB3